1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215
|
<!--
SPDX-FileCopyrightText: The WebKit GTK and WPE teams
SPDX-License-Identifier: BSD, LGPL-2.1
-->
<!DOCTYPE html>
<html lang="en">
<head>
<title>WPEWebKit.PolicyDecisionType</title>
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta charset="utf-8" />
<meta property="og:type" content="website"/>
<meta property="og:title" content="WPEWebKit.PolicyDecisionType"/>
<meta property="og:description" content="Reference for WPEWebKit.PolicyDecisionType"/>
<meta name="twitter:title" content="WPEWebKit.PolicyDecisionType"/>
<meta name="twitter:description" content="Reference for WPEWebKit.PolicyDecisionType"/>
<meta name="twitter:card" content="summary"/>
<link rel="stylesheet" href="style.css" type="text/css" />
<script src="wpe2-urlmap.js"></script>
<script src="fzy.js"></script>
<script src="search.js"></script>
<script src="main.js"></script>
</head>
<body>
<div id="body-wrapper" tabindex="-1">
<nav class="sidebar devhelp-hidden">
<div class="search section">
<form id="search-form" autocomplete="off">
<input id="search-input" type="text" name="do-not-autocomplete" placeholder="Click, or press 's' to search" autocomplete="off"/>
</form>
</div>
<div class="section namespace">
<h3><a href="index.html">WPEWebKit</a></h3>
<p>API Version: 2.0</p>
<p>Library Version: 2.50.5</p>
</div>
<div class="section">
<h5>Type</h5>
<div class="links">
<a class="current" href="enum.PolicyDecisionType.html">PolicyDecisionType</a>
</div>
</div>
<div class="section generator">
<p>Generated by <a href="https://gitlab.gnome.org/GNOME/gi-docgen">gi-docgen</a> 2023.1</p>
</div>
</nav>
<button id="btn-to-top" class="hidden"><span class="up-arrow"></span></button>
<section id="main" class="content">
<header>
<h3>Enumeration</h3>
<h1><a href="index.html">WPEWebKit</a><span class="sep"></span>PolicyDecisionType</h1>
</header>
<section>
<div class="docblock">
<p></p>
</div>
<div class="declaration toggle-wrapper">
<h4 style="display:flex;" id="declaration">
Declaration
<a href="#declaration" class="anchor"></a>
</h4>
<div class="docblock">
<pre><code>enum WPEWebKit.PolicyDecisionType</code></pre>
</div>
</div>
<div class="description toggle-wrapper">
<h4 style="display:flex;" id="description">
Description
<a href="#description" class="anchor"></a>
<a class="srclink" title="go to source location" href="https://github.com/WebKit/WebKit/tree/main/WebKitBuild/WPE/Release/DerivedSources/WebKit/wpe/WebKitWebView.h#L73">[src]</a>
</h4>
<div class="docblock">
<p>Enum values used for determining the type of a policy decision during
<code>WebKitWebView::decide-policy</code>.</p>
</div>
<div class="docblock">
</div>
</div>
<div class="members toggle-wrapper">
<h4 id="members">
Members
<a href="#members" class="anchor"></a>
</h4>
<div class="docblock">
<table class="enum-members">
<tr>
<th>Name</th>
<th>Description</th>
</tr>
<tr>
<td><a id="navigation_action" href="#navigation_action"><code title="Value: 0">WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION</code></a></td>
<td><p>This type of policy decision
is requested when WebKit is about to navigate to a new page in either the
main frame or a subframe. Acceptable policy decisions are either
<code>webkit_policy_decision_use()</code> or webkit_policy_decision_ignore(). This
type of policy decision is always a <code>WebKitNavigationPolicyDecision</code>.</p></td>
</tr>
<tr>
<td><a id="new_window_action" href="#new_window_action"><code title="Value: 1">WEBKIT_POLICY_DECISION_TYPE_NEW_WINDOW_ACTION</code></a></td>
<td><p>This type of policy decision
is requested when WebKit is about to create a new window. Acceptable policy
decisions are either <code>webkit_policy_decision_use()</code> or
webkit_policy_decision_ignore(). This type of policy decision is always
a <code>WebKitNavigationPolicyDecision</code>. These decisions are useful for implementing
special actions for new windows, such as forcing the new window to open
in a tab when a keyboard modifier is active or handling a special
target attribute on <a> elements.</p></td>
</tr>
<tr>
<td><a id="response" href="#response"><code title="Value: 2">WEBKIT_POLICY_DECISION_TYPE_RESPONSE</code></a></td>
<td><p>This type of decision is used when WebKit has
received a response for a network resource and is about to start the load.
Note that these resources include all subresources of a page such as images
and stylesheets as well as main documents. Appropriate policy responses to
this decision are webkit_policy_decision_use(), webkit_policy_decision_ignore(),
or webkit_policy_decision_download(). This type of policy decision is always
a <code>WebKitResponsePolicyDecision</code>. This decision is useful for forcing
some types of resources to be downloaded rather than rendered in the WebView
or to block the transfer of resources entirely.</p></td>
</tr>
</table>
</div>
</div>
</section>
</section>
<div id="toc" class="toc">
<nav aria-labelledby="toc-title">
<p id="toc-title">Content</p>
<ul class="toc-list">
<li class="toc-list-item"><a href="#description"><span class="link-text">Description</span></a></li>
<li class="toc-list-item"><a href="#members"><span class="link-text">Members</span></a></li>
</ul>
</nav>
</div>
<section id="search" class="content hidden"></section>
<footer>
</footer>
</div>
</body>
</html>
|